[Zope3-checkins] CVS: Zope3/src/zope/app/browser/workflow - configure.zcml:1.4 definition.py:1.2

Jim Fulton jim@zope.com
Sat, 21 Jun 2003 17:22:38 -0400


Update of /cvs-repository/Zope3/src/zope/app/browser/workflow
In directory cvs.zope.org:/tmp/cvs-serv2745/src/zope/app/browser/workflow

Modified Files:
	configure.zcml definition.py 
Log Message:
Major refactoring to reflect change in terminology from
"configuration" to "registration" to refer to the configuration of how
objects are used (as opposed to their internal configuration).


=== Zope3/src/zope/app/browser/workflow/configure.zcml 1.3 => 1.4 ===
--- Zope3/src/zope/app/browser/workflow/configure.zcml:1.3	Fri Jun 13 13:53:34 2003
+++ Zope3/src/zope/app/browser/workflow/configure.zcml	Sat Jun 21 17:22:07 2003
@@ -8,7 +8,7 @@
   for="zope.app.interfaces.workflow.IWorkflowService"
   name="index.html"
   template="workflows.pt"
-  class="zope.app.browser.services.configuration.NameComponentConfigurableView"
+  class="zope.app.browser.services.registration.NameComponentRegistryView"
   permission="zope.ManageServices"  
   />
 
@@ -24,25 +24,25 @@
 
 
 
-<!-- ProcessDefinition Configuration -->
+<!-- ProcessDefinition Registration -->
 
 <browser:page
   for="zope.app.interfaces.workflow.IProcessDefinition"
-  name="useConfiguration.html"
+  name="useRegistration.html"
   template="useprocessdefinitionconfig.pt"
-  class=".definition.UseConfiguration"
+  class=".definition.Registered"
   permission="zope.workflow.ManageProcessDefinitions"
-  menu="zmi_views" title="Configurations"
+  menu="zmi_views" title="Registrations"
   />
 
 
 <browser:addform
   for="zope.app.interfaces.workflow.IProcessDefinition"
-  name="addConfiguration.html"
-  schema="zope.app.interfaces.workflow.IProcessDefinitionConfiguration"
-  class="zope.app.browser.services.configuration.AddComponentConfiguration"
+  name="addRegistration.html"
+  schema="zope.app.interfaces.workflow.IProcessDefinitionRegistration"
+  class="zope.app.browser.services.registration.AddComponentRegistration"
   permission="zope.workflow.ManageProcessDefinitions"
-  content_factory="zope.app.workflow.service.ProcessDefinitionConfiguration"
+  content_factory="zope.app.workflow.service.ProcessDefinitionRegistration"
   arguments="name componentPath"
   set_after_add="status"
   fields="name componentPath permission status"
@@ -51,8 +51,8 @@
 <browser:editform
   name="index.html"
   menu="zmi_views" title="Edit"
-  schema="zope.app.interfaces.workflow.IProcessDefinitionConfiguration"
-  label="ProcessDefinition Configuration"
+  schema="zope.app.interfaces.workflow.IProcessDefinitionRegistration"
+  label="ProcessDefinition Registration"
   permission="zope.workflow.ManageProcessDefinitions"
   fields="name componentPath permission status"
   />


=== Zope3/src/zope/app/browser/workflow/definition.py 1.1 => 1.2 ===
--- Zope3/src/zope/app/browser/workflow/definition.py:1.1	Thu May  8 13:27:17 2003
+++ Zope3/src/zope/app/browser/workflow/definition.py	Sat Jun 21 17:22:07 2003
@@ -11,7 +11,7 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
 """ProcessDefinition configuration adding view
  
 $Id$
 """
@@ -20,20 +20,20 @@
 from zope.component import getAdapter, getView, getUtility
 from zope.publisher.browser import BrowserView
 from zope.app.traversing import traverse
-from zope.app.interfaces.services.configuration import IUseConfiguration
+from zope.app.interfaces.services.registration import IRegistered
 from zope.app.interfaces.workflow import IProcessDefinitionImportExport
 
 
 
-class UseConfiguration(BrowserView):
-    """View for displaying the configurations for a process definition
+class Registered(BrowserView):
+    """View for displaying the registrations for a process definition
     """
 
     def uses(self):
         """Get a sequence of configuration summaries
         """
         component = self.context
-        useconfig = getAdapter(component, IUseConfiguration)
+        useconfig = getAdapter(component, IRegistered)
         result = []
         for path in useconfig.usages():
             config = traverse(component, path)
@@ -11,7 +11,7 @@
 #
 ##############################################################################
-"""ProcessDefinition configuration adding view
+"""ProcessDefinition registration adding view
  
 $Id$
@@ -20,20 +20,20 @@
 
     def uses(self):
-        """Get a sequence of configuration summaries
+        """Get a sequence of registration summaries
         """
         component = self.context